Corrections Library
-------------------

.. automodule:: pykoala.corrections
   :members: CorrectionBase
   :undoc-members:
   :show-inheritance:

Astrometry
---------------------------------------------------

.. automodule:: pykoala.corrections.astrometry
   :members:
   :undoc-members:
   :show-inheritance:

Atmospheric Corrections
---------------------------------------------------

.. automodule:: pykoala.corrections.atmospheric_corrections
   :members:
   :undoc-members:
   :show-inheritance:

External data
---------------------------------------------------

.. automodule:: pykoala.corrections.external_data
   :members:
   :undoc-members:
   :show-inheritance:

Flux Calibration
--------------------------------------------

.. automodule:: pykoala.corrections.flux_calibration
   :members:
   :undoc-members:
   :show-inheritance:

Sky
------------------------------

.. automodule:: pykoala.corrections.sky
   :members:
   :undoc-members:
   :show-inheritance:

Throughput
-------------------------------------

.. automodule:: pykoala.corrections.throughput
   :members:
   :undoc-members:
   :show-inheritance:

Wavelength
-------------------------------------

.. automodule:: pykoala.corrections.wavelength
   :members: WavelengthOffset, WavelengthCorrection, SolarCrossCorrOffset
   :undoc-members:
   :show-inheritance:
